@@ -8,6 +8,7 @@
 module Git.Repair (
 	runRepair,
 	runRepairOf,
+	successfulRepair,
 	cleanCorruptObjects,
 	retrieveMissingObjects,
 	resetLocalBranches,
@@ -47,7 +48,7 @@ import Data.Tuple.Utils
  - Since git fsck may crash on corrupt objects, and so not
  - report the full set of corrupt or missing objects,
  - this removes corrupt objects, and re-runs fsck, until it
- - stabalizes.
+ - stabilizes.
  -
  - To remove corrupt objects, unpack all packs, and remove the packs
  - (to handle corrupt packs), and remove loose object files.
@@ -78,11 +79,13 @@ cleanCorruptObjects mmissing r = check mmissing
 		putStrLn "Re-running git fsck to see if it finds more problems."
 		v <- findBroken False r
 		case v of
-			Nothing -> error $ unwords
-				[ "git fsck found a problem, which was not corrected after removing"
-				, show (S.size oldbad)
-				, "corrupt objects."
-				]
+			Nothing -> do
+				hPutStrLn stderr $ unwords
+					[ "git fsck found a problem, which was not corrected after removing"
+					, show (S.size oldbad)
+					, "corrupt objects."
+					]
+				return S.empty
 			Just newbad -> do
 				removed <- removeLoose r newbad
 				let s = S.union oldbad newbad
@@ -452,6 +455,9 @@ runRepair forced g = do
 			putStrLn "No problems found."
 			return (True, S.empty, [])
 
+successfulRepair :: (Bool, MissingObjects, [Branch]) -> Bool
+successfulRepair = fst3
+
 runRepairOf :: FsckResults -> Bool -> Maybe FilePath -> Repo -> IO (Bool, MissingObjects, [Branch])
 runRepairOf fsckresult forced referencerepo g = do
 	missing <- cleanCorruptObjects fsckresult g
@@ -512,8 +518,12 @@ runRepairOf fsckresult forced referencerepo g = do
 	
 	corruptedindex = do
 		nukeIndex g
+		-- The corrupted index can prevent fsck from finding other
+		-- problems, so re-run repair.
+		fsckresult' <- findBroken False g
+		result <- runRepairOf fsckresult' forced referencerepo g
 		putStrLn "Removed the corrupted index file. You should look at what files are present in your working tree and git add them back to the index when appropriate."
-		return (True, S.empty, [])
+		return result
 
 	successfulfinish stillmissing modifiedbranches = do
 		mapM_ putStrLn
@@ -525,10 +535,10 @@ runRepairOf fsckresult forced referencerepo g = do
 	unsuccessfulfinish stillmissing = do
 		if repoIsLocalBare g
 			then do
-				putStrLn "If you have a clone of this bare repository, you should add it as a remote of this repository, and re-run git-recover-repository."
-				putStrLn "If there are no clones of this repository, you can instead run git-recover-repository with the --force parameter to force recovery to a possibly usable state."
+				putStrLn "If you have a clone of this bare repository, you should add it as a remote of this repository, and retry."
+				putStrLn "If there are no clones of this repository, you can instead retry with the --force parameter to force recovery to a possibly usable state."
 				return (False, stillmissing, [])
 			else needforce stillmissing
 	needforce stillmissing = do
-		putStrLn "To force a recovery to a usable state, run this command again with the --force parameter."
+		putStrLn "To force a recovery to a usable state, retry with the --force parameter."
 		return (False, stillmissing, [])
