@@ -11,6 +11,7 @@ module Messages (
 	showAction,
 	showProgress,
 	metered,
+	meteredBytes,
 	showSideAction,
 	doSideAction,
 	doQuietSideAction,
@@ -22,28 +23,36 @@ module Messages (
 	showEndResult,
 	showErr,
 	warning,
+	warningIO,
+	fileNotFound,
 	indent,
 	maybeShowJSON,
 	showFullJSON,
 	showCustom,
 	showHeader,
 	showRaw,
-	
-	setupConsole
+	setupConsole,
+	enableDebugOutput,
+	disableDebugOutput
 ) where
 
 import Text.JSON
 import Data.Progress.Meter
 import Data.Progress.Tracker
 import Data.Quantity
+import System.Log.Logger
+import System.Log.Formatter
+import System.Log.Handler (setFormatter, LogHandler)
+import System.Log.Handler.Simple
+import qualified Data.Set as S
 
 import Common
 import Types
 import Types.Messages
-import Types.Key
-import Types.Remote
-import qualified Annex
 import qualified Messages.JSON as JSON
+import Types.Key
+import qualified Annex
+import Utility.Metered
 
 showStart :: String -> String -> Annex ()
 showStart command file = handle (JSON.start command $ Just file) $
@@ -63,31 +72,40 @@ showProgress = handle q $
 
 {- Shows a progress meter while performing a transfer of a key.
  - The action is passed a callback to use to update the meter. -}
-metered :: (Maybe MeterUpdate) -> Key -> (MeterUpdate -> Annex a) -> Annex a
-metered combinemeterupdate key a = withOutputType $ go (keySize key)
-	where
-		go (Just size) NormalOutput = do
-			progress <- liftIO $ newProgress "" size
-			meter <- liftIO $ newMeter progress "B" 25 (renderNums binaryOpts 1)
-			showOutput
-			liftIO $ displayMeter stdout meter
-			r <- a $ \n -> liftIO $ do
-				incrP progress n
-				displayMeter stdout meter
-				maybe noop (\m -> m n) combinemeterupdate
-			liftIO $ clearMeter stdout meter
-			return r
-                go _ _ = a (const noop)
+metered :: Maybe MeterUpdate -> Key -> (MeterUpdate -> Annex a) -> Annex a
+metered combinemeterupdate key a = go (keySize key)
+  where
+	go (Just size) = meteredBytes combinemeterupdate size a
+	go _ = a (const noop)
+
+{- Shows a progress meter while performing an action on a given number
+ - of bytes. -}
+meteredBytes :: Maybe MeterUpdate -> Integer -> (MeterUpdate -> Annex a) -> Annex a
+meteredBytes combinemeterupdate size a = withOutputType go
+  where
+	go NormalOutput = do
+		progress <- liftIO $ newProgress "" size
+		meter <- liftIO $ newMeter progress "B" 25 (renderNums binaryOpts 1)
+		showOutput
+		r <- a $ \n -> liftIO $ do
+			setP progress $ fromBytesProcessed n
+			displayMeter stdout meter
+			maybe noop (\m -> m n) combinemeterupdate
+		liftIO $ clearMeter stdout meter
+		return r
+	go _ = a (const noop)
 
 showSideAction :: String -> Annex ()
 showSideAction m = Annex.getState Annex.output >>= go
-	where
-		go (MessageState v StartBlock) = do
+  where
+	go st
+		| sideActionBlock st == StartBlock = do
 			p
-	 		Annex.changeState $ \s -> s { Annex.output = MessageState v InBlock }
-		go (MessageState _ InBlock) = return ()
-		go _ = p
-		p = handle q $ putStrLn $ "(" ++ m ++ "...)"
+			let st' = st { sideActionBlock = InBlock }
+			Annex.changeState $ \s -> s { Annex.output = st' }
+		| sideActionBlock st == InBlock = return ()
+		| otherwise = p
+	p = handle q $ putStrLn $ "(" ++ m ++ "...)"
 			
 showStoringStateAction :: Annex ()
 showStoringStateAction = showSideAction "Recording state in git"
@@ -106,8 +124,8 @@ doSideAction' b a = do
 	o <- Annex.getState Annex.output
 	set $ o { sideActionBlock = b }
 	set o `after` a
-	where
-		set o = Annex.changeState $ \s -> s {  Annex.output = o }
+  where
+	set o = Annex.changeState $ \s -> s {  Annex.output = o }
 
 showOutput :: Annex ()
 showOutput = handle q $
@@ -125,10 +143,10 @@ showEndFail = showEndResult False
 
 showEndResult :: Bool -> Annex ()
 showEndResult ok = handle (JSON.end ok) $ putStrLn msg
-	where
-		msg
-			| ok = "ok"
-			| otherwise = "failed"
+  where
+	msg
+		| ok = "ok"
+		| otherwise = "failed"
 
 showErr :: (Show a) => a -> Annex ()
 showErr e = warning' $ "git-annex: " ++ show e
@@ -143,8 +161,26 @@ warning' w = do
 		hFlush stdout
 		hPutStrLn stderr w
 
+warningIO :: String -> IO ()
+warningIO w = do
+	putStr "\n"
+	hFlush stdout
+	hPutStrLn stderr w
+
+{- Displays a warning one time about a file the user specified not existing. -}
+fileNotFound :: FilePath -> Annex ()
+fileNotFound file = do
+	st <- Annex.getState Annex.output
+	let shown = fileNotFoundShown st
+	when (S.notMember file shown) $ do
+		let shown' = S.insert file shown
+		let st' = st { fileNotFoundShown = shown' }
+		Annex.changeState $ \s -> s { Annex.output = st' }
+		liftIO $ hPutStrLn stderr $ unwords
+			[ "git-annex:", file, "not found" ]
+
 indent :: String -> String
-indent = join "\n" . map (\l -> "  " ++ l) . lines
+indent = intercalate "\n" . map (\l -> "  " ++ l) . lines
 
 {- Shows a JSON fragment only when in json mode. -}
 maybeShowJSON :: JSON a => [(String, a)] -> Annex ()
@@ -153,9 +189,9 @@ maybeShowJSON v = handle (JSON.add v) q
 {- Shows a complete JSON value, only when in json mode. -}
 showFullJSON :: JSON a => [(String, a)] -> Annex Bool
 showFullJSON v = withOutputType $ liftIO . go
-	where
-		go JSONOutput = JSON.complete v >> return True
-		go _ = return False
+  where
+	go JSONOutput = JSON.complete v >> return True
+	go _ = return False
 
 {- Performs an action that outputs nonstandard/customized output, and
  - in JSON mode wraps its output in JSON.start and JSON.end, so it's
@@ -174,20 +210,30 @@ showHeader h = handle q $
 showRaw :: String -> Annex ()
 showRaw s = handle q $ putStrLn s
 
-{- This avoids ghc's output layer crashing on invalid encoded characters in
- - filenames when printing them out.
- -}
 setupConsole :: IO ()
 setupConsole = do
+	s <- setFormatter
+		<$> streamHandler stderr DEBUG
+		<*> pure (simpleLogFormatter "[$time] $msg")
+	updateGlobalLogger rootLoggerName (setLevel NOTICE . setHandlers [s])
+	{- This avoids ghc's output layer crashing on
+	 - invalid encoded characters in
+	 - filenames when printing them out. -}
 	fileEncoding stdout
 	fileEncoding stderr
 
+enableDebugOutput :: IO ()
+enableDebugOutput = updateGlobalLogger rootLoggerName $ setLevel DEBUG
+
+disableDebugOutput :: IO ()
+disableDebugOutput = updateGlobalLogger rootLoggerName $ setLevel NOTICE
+
 handle :: IO () -> IO () -> Annex ()
 handle json normal = withOutputType go
-	where
-		go NormalOutput = liftIO normal
-		go QuietOutput = q
-		go JSONOutput = liftIO $ flushed json
+  where
+	go NormalOutput = liftIO normal
+	go QuietOutput = q
+	go JSONOutput = liftIO $ flushed json
 
 q :: Monad m => m ()
 q = noop
